==> libbtm-java_2.1.2.orig.tar.gz: btm-dist-2.1.2/src/bitronix/tm/BitronixTransactionSynchronizationRegistryObjectFactory.java <==
/*
 * Bitronix Transaction Manager
 *
 * Copyright (c) 2010, Bitronix Software.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA 02110-1301 USA
 */
package bitronix.tm;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.naming.Context;
import javax.naming.Name;
import javax.naming.spi.ObjectFactory;
import java.util.Hashtable;

/**
 * {@link bitronix.tm.BitronixTransactionSynchronizationRegistry} object factory for JNDI references.
 *
 * @author lorban
 */
public class BitronixTransactionSynchronizationRegistryObjectFactory implements ObjectFactory {

    private final static Logger log = LoggerFactory.getLogger(BitronixTransactionSynchronizationRegistryObjectFactory.class);

    /**
     * Since there can be only one synchronization registry per VM instance, this method always returns a reference
     * to the unique BitronixTransactionSynchronizationRegistry object.
     * @see bitronix.tm.BitronixTransactionSynchronizationRegistry
     * @return the unique synchronization registry instance.
     */
    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable environment) throws Exception {
        if (log.isDebugEnabled()) log.debug("returning the unique synchronization registry instance");
        return TransactionManagerServices.getTransactionSynchronizationRegistry();
    }


}

==> libbtm-java_2.1.4.orig.tar.gz: btm-dist-2.1.4/src/bitronix/tm/BitronixTransactionSynchronizationRegistryObjectFactory.java <==
/*
 * Bitronix Transaction Manager
 *
 * Copyright (c) 2010, Bitronix Software.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA 02110-1301 USA
 */
package bitronix.tm;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.naming.Context;
import javax.naming.Name;
import javax.naming.spi.ObjectFactory;
import java.util.Hashtable;

/**
 * {@link bitronix.tm.BitronixTransactionSynchronizationRegistry} object factory for JNDI references.
 *
 * @author lorban
 */
public class BitronixTransactionSynchronizationRegistryObjectFactory implements ObjectFactory {

    private final static Logger log = LoggerFactory.getLogger(BitronixTransactionSynchronizationRegistryObjectFactory.class);

    /**
     * Since there can be only one synchronization registry per VM instance, this method always returns a reference
     * to the unique BitronixTransactionSynchronizationRegistry object.
     * @see bitronix.tm.BitronixTransactionSynchronizationRegistry
     * @return the unique synchronization registry instance.
     */
    public Object getObjectInstance(Object obj, Name name, Context nameCtx, Hashtable<?,?> environment) throws Exception {
        if (log.isDebugEnabled()) log.debug("returning the unique synchronization registry instance");
        return TransactionManagerServices.getTransactionSynchronizationRegistry();
    }


}
